@@ -296,7 +296,8 @@ TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE, type = "defaul
     vars <- c("date", pollutant)
 
 
-    if (!avg.time %in% c("year", "month", "season")) stop ("avg.time can only be 'month', 'season' or 'year'.")
+    if (!avg.time %in% c("year", "month", "season")) 
+      stop ("avg.time can only be 'month', 'season' or 'year'.")
 
     ## if data clearly annual, then assume annual
     interval <- find.time.interval(mydata$date)
@@ -321,14 +322,15 @@ TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE, type = "defaul
     end.month <-   endMonth(mydata$date)
 
 
-    mydata <- plyr::ddply(mydata, type, timeAverage, avg.time = avg.time,
-                         statistic = statistic, percentile = percentile,
-                         data.thresh = data.thresh)
+    mydata <- group_by_(mydata, type) %>%
+      do(timeAverage(., avg.time = avg.time, statistic = statistic, 
+                     percentile = percentile,
+                     data.thresh = data.thresh))
     
 
     process.cond <- function(mydata) {
 
-        if (all(is.na(mydata[ , pollutant]))) return()       
+        if (all(is.na(mydata[[pollutant]]))) return()       
 
         ## sometimes data have long trailing NAs, so start and end at
         ## first and last data
@@ -346,16 +348,16 @@ TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE, type = "defaul
 
             mydata$date <- as.Date(mydata$date)
 
-            deseas <- mydata[, pollutant]
+            deseas <- mydata[[pollutant]]
 
             ## can't deseason less than 2 years of data
             if (nrow(mydata) <= 24) deseason <- FALSE
 
             if (deseason) {
                 ## interpolate missing data
-                mydata[, pollutant] <- approx(mydata[, pollutant], n = length(mydata[, pollutant]))$y
+                mydata[[pollutant]] <- approx(mydata[[pollutant]], n = length(mydata[[pollutant]]))$y
 
-                myts <- ts(mydata[, pollutant], start = c(start.year, start.month),
+                myts <- ts(mydata[[pollutant]], start = c(start.year, start.month),
                            end = c(end.year, end.month), frequency = 12)
                 ## key thing is to allow the seanonal cycle to vary, hence
                 ## s.window should not be "periodic"; set quite high to avoid
@@ -375,7 +377,7 @@ TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE, type = "defaul
         } else {
 
             ## assume annual
-            all.results <- data.frame(date = as.Date(mydata$date), conc = mydata[ , pollutant])
+            all.results <- data.frame(date = as.Date(mydata$date), conc = mydata[[pollutant]])
             results <- na.omit(all.results)
         }
 
@@ -388,7 +390,11 @@ TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE, type = "defaul
         results
     }
     
-    split.data <- plyr::ddply(mydata, type,  process.cond)
+
+    split.data <- group_by_(mydata, type) %>%
+      do(process.cond(.))
+    
+    
     if (nrow(split.data) < 2) return()
 
 
@@ -423,15 +429,20 @@ TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE, type = "defaul
 
     ## aggregated results
 
-    res2 <- plyr::ddply(split.data, c(type, "p.stars"), numcolwise(mean), na.rm = TRUE)
+    res2 <- group_by_(split.data, type, "p.stars") %>% 
+      summarise_each(funs(mean(., na.rm = TRUE)))
 
     ## calculate percentage changes in slope and uncertainties
     ## need start and end dates (in days) to work out concentrations at those points
     ## percentage change defind as 100.(C.end/C.start -1) / duration
 
-
-    start <- plyr::ddply(split.data, type, function (x) head(x, 1))
-    end <- plyr::ddply(split.data, type, function (x) tail(x, 1))
+    
+    start <- group_by_(split.data, type) %>% 
+      do(head(., 1))
+    
+    end <- group_by_(split.data, type) %>% 
+      do(tail(., 1))
+    
     percent.change <- merge(start, end, by = type, suffixes = c(".start", ".end"))
 
     percent.change <- transform(percent.change, slope.percent = 100 * 365 *
