@@ -36,7 +36,7 @@
 quickText <- function(text, auto.text = TRUE){
 
     ## the lookup table version
-
+    
     ## #return if auto.text false
     if (!auto.text) return(ans <- text)
 
@@ -54,15 +54,18 @@ quickText <- function(text, auto.text = TRUE){
     ans <- gsub("co ", "' 'CO ' '", ans)
     ans <- gsub("co,", "' 'CO,' '", ans)
     ans <- gsub("nmhc", "' 'NMHC' '", ans)
-    ans <- gsub("ws", "' 'wind spd.' '", ans)
+
+    
+    ans <- if (nchar(as.character(text)) == 2 && length(grep("ws", text)) > 0)
+               gsub("ws", "' 'wind spd.' '", ans) else ans
     ans <- gsub("wd", "' 'wind dir.' '", ans)
     ans <- gsub("rh ", "' 'relative humidity' '", ans)
-                                        #   ans <- gsub("temp", "' 'temperature' '", ans)
     ans <- gsub("PM10", "' 'PM' [10] * '", ans)
     ans <- gsub("pm10", "' 'PM' [10] * '", ans)
     ans <- gsub("pm1", "' 'PM' [1] * '", ans)
     ans <- gsub("PM1", "' 'PM' [1] * '", ans)
     ans <- gsub("pmc", "' 'PM' [coarse] * '", ans)
+    
     ans <- gsub("pmcoarse", "' 'PM' [coarse] * '", ans)
     ans <- gsub("PMc", "' 'PM' [coarse] * '", ans)
     ans <- gsub("PMcoarse", "' 'PM' [coarse] * '", ans)
