@@ -380,9 +380,10 @@ timePlot <- function(mydata, pollutant = "nox", group = FALSE, stack = FALSE,
 
         if (length(percentile) > 1) {
 
-            mydata <- plyr::ddply(mydata, type, calcPercentile, pollutant = pollutant,
-                            avg.time = avg.time, data.thresh = data.thresh,
-                            percentile = percentile)
+           mydata <- group_by_(mydata, type) %>%
+             do(calcPercentile(., pollutant = pollutant, avg.time = avg.time, 
+                               data.thresh = data.thresh,
+                               percentile = percentile))
 
             pollutant <-  paste("percentile.", percentile,  sep = "")
 
@@ -390,9 +391,10 @@ timePlot <- function(mydata, pollutant = "nox", group = FALSE, stack = FALSE,
 
         } else {
             
-            mydata <- plyr::ddply(mydata, type, timeAverage, avg.time = avg.time,
-                            statistic = statistic, percentile = percentile,
-                            data.thresh = data.thresh)
+            mydata <- group_by_(mydata, type) %>%
+              do(timeAverage(., pollutant = pollutant, avg.time = avg.time, 
+                                data.thresh = data.thresh,
+                                percentile = percentile))
         }
     }
     
@@ -441,14 +443,18 @@ timePlot <- function(mydata, pollutant = "nox", group = FALSE, stack = FALSE,
 
         if (normalise == "mean") {
 
-            mydata <-  plyr::ddply(mydata, .(variable), divide.by.mean)
+            mydata <- group_by(mydata, variable) %>%
+              do(divide.by.mean(.))
 
         } else {
 
             ## scale value to 100 at specific date
 
             thedate <- as.POSIXct(strptime(normalise, format = "%d/%m/%Y", tz = "GMT"))
-            mydata <- plyr::ddply(mydata, .(variable), norm.by.date, thedate = thedate)
+           
+            
+            mydata <- group_by(mydata, variable) %>%
+              do(norm.by.date(., thedate = thedate))
         }
     }
 
